- bc71693 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- b8c1af0 Update README.md (Dinesh Ravi, 2025-07-14)
- 51d5ef2 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- 82770a0 upate change log (Dinesh, 2025-07-14)
- f2c4cbf Update README.md (Dinesh Ravi, 2025-07-14)
- 2bff2ec add new screenshots (Dinesh Ravi, 2025-07-14)
- ca272df fix stewards no attribute value (Dinesh Ravi, 2025-07-14)
- 49786d0 fix missing print_licenses_table_with_steward (Dinesh Ravi, 2025-07-14)
- c4612dd add print_licenses_table_with_steward (Dinesh Ravi, 2025-07-14)
- 16ed910 remove the debug (Dinesh Ravi, 2025-07-14)
- ca0c062 add enum value (Dinesh Ravi, 2025-07-14)
- 1d79f6f use set add (Dinesh Ravi, 2025-07-14)
- 0419c54 fix str(keyword) (Dinesh Ravi, 2025-07-14)
- 6afe6cc debug keyword (Dinesh Ravi, 2025-07-14)
- b706f90 fix enum keyword (Dinesh Ravi, 2025-07-14)
- 3871702 fix keyword object not iterable (Dinesh Ravi, 2025-07-14)
- 511d630 revert enum (Dinesh Ravi, 2025-07-14)
- a747612 Unpack enum keywords (Dinesh Ravi, 2025-07-14)
- 0b27a51 fix case sensitive keyword option (Dinesh Ravi, 2025-07-14)
- 27ddad0 fix elif (Dinesh Ravi, 2025-07-14)
- 311aa2b fix keyword case (Dinesh Ravi, 2025-07-14)
- 05c1425 fix unpaccking variable (Dinesh Ravi, 2025-07-14)
- cbf6c64 added stewards and keywords (Dinesh Ravi, 2025-07-14)
- 1240891 Add description in toml (Dinesh, 2025-07-14)
- db1a396 fix source link in Readme (Dinesh, 2025-07-14)
- 4bee5fb Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- f60ba74 Update README.md (Dinesh Ravi, 2025-07-14)
- b3b4d68 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- ccdadff Update README.md (Dinesh Ravi, 2025-07-14)
- e5c249e update license link in readme (Dinesh Ravi, 2025-07-14)
- 4f73381 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- 0107c2c Update README.md (Dinesh Ravi, 2025-07-14)
- 4b1d89c update to 0.1.1 (Dinesh Ravi, 2025-07-14)
- c180117 Update README.md (Dinesh Ravi, 2025-07-14)
- e905a5a updated readme (Dinesh, 2025-07-14)
- 5a9d3fa all license screenshot (Dinesh, 2025-07-14)
- d2a2d99 improve change log (Dinesh, 2025-07-14)
- 5568ec7 add screenshots (Dinesh, 2025-07-14)
- 6227d95 update changelog (Dinesh, 2025-07-14)
- f943e59 first commit (Dinesh, 2025-07-14)